.. raw:: html
    <head>
        <meta http-equiv='refresh' content='0; URL=./index.html#components'>
    </head>

# Components

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

Components overview <components/components_overview>
Custom components <components/components_custom.md>
```
